@@ -14,7 +14,8 @@ Based on the Apache License 2.0 open source protocol.
 def singleton_pattern(cls, *args, **kwargs):
     """
     [ 单例模式装饰器 ]
-    * 无
+
+    * NOT MESSAGE
 
     """
 
@@ -26,3 +27,18 @@ def singleton_pattern(cls, *args, **kwargs):
         return instances[cls]
 
     return _singleton_pattern
+
+
+CONST_SINGLETON_PATERN = singleton_pattern
+"""[ 常量单例模式装饰器 ]
+
+* NOT MESSAGE
+
+"""
+
+CLASS_SINGLETON_PATERN = singleton_pattern
+"""[ 类单例模式装饰器 ]
+
+* NOT MESSAGE
+
+"""
