@@ -10,53 +10,50 @@ Based on the Apache License 2.0 open source protocol.
 
 """
 
+
 __all__ = ['Log']
 
 
 import time
 import logging
 
-from rains.common.const import ConstPath
-from rains.common.decorator import singleton_pattern
+from rains.const.const_file import ConstPath
+from rains.common.decorator import CLASS_SINGLETON_PATERN
 
 
-# 日志服务::记录器日志级别
+# 日志服务 :: 记录器日志级别
 _CONFIG_LOGGING_LEVEL = 'DEBUG'
 
-# 日志服务::默认流处理器的日志级别
+# 日志服务 :: 默认流处理器的日志级别
 _CONFIG_BASE_HANDLE_LEVEL = 'INFO'
 
-# 日志服务::文件流处理器的日志级别
+# 日志服务 :: 文件流处理器的日志级别
 _CONFIG_FILE_HANDLE_LEVELS = ['DEBUG', 'INFO', 'ERROR', 'WARNING']
 
-# 日志服务::日志输出格式对象
+# 日志服务 :: 日志输出格式对象
 _CONFIG_OUTPUT_STRUCTURE = logging.Formatter('[%(asctime)s] [%(levelname)7s] %(message)s')
 
 
-@singleton_pattern
+@CLASS_SINGLETON_PATERN
 class Log(object):
     """
     [ 日志服务 ]
-    * 无
+
+    * NOT MESSAGE
 
     """
 
     _logger: logging.Logger
-    """ 记录器 """
+    """ [ 记录器对象 ] """
 
     def __init__(self):
         """
-        [ 初始化 ]
-        * 无
+        [ 日志服务 ]
 
-        [ 必要参数 ]
-        * 无
+        * 初始化。
 
-        [ 可选参数 ]
-        * 无
-
-        [ 返回内容 ]
-        * 无
+        Raises:
+            CreationLogLivingError: [ 创建日志实例异常 ]
 
         """
 
@@ -71,22 +68,17 @@ class Log(object):
             # 创建文件流处理器
             self._creation_file_handle()
 
-        except BaseException as e:
-            raise Exception(f"实例化日志服务异常:: { e } ")
+        except BaseException as err:
+            raise CreationLogLivingError(str(err))
 
-    def debug(self, message):
+    def debug(self, message: str):
         """
-        [ DEBUG ]
-        * 无
+        [ 记录 DEBUG ]
 
-        [ 必要参数 ]
-        * 无
+        * NOT MESSAGE
 
-        [ 可选参数 ]
-        * 无
-
-        [ 返回内容 ]
-        * 无
+        Args:
+            message (str): [ 输出的日志信息 ]
 
         """
 
@@ -94,17 +86,12 @@ class Log(object):
 
     def info(self, message):
         """
-        [ INFO ]
-        * 无
+        [ 记录 INFO ]
 
-        [ 必要参数 ]
-        * 无
+        * NOT MESSAGE
 
-        [ 可选参数 ]
-        * 无
-
-        [ 返回内容 ]
-        * 无
+        Args:
+            message (str): [ 输出的日志信息 ]
 
         """
 
@@ -112,17 +99,12 @@ class Log(object):
 
     def warning(self, message):
         """
-        [ WARNING ]
-        * 无
+        [ 记录 WARNING ]
 
-        [ 必要参数 ]
-        * 无
+        * NOT MESSAGE
 
-        [ 可选参数 ]
-        * 无
-
-        [ 返回内容 ]
-        * 无
+        Args:
+            message (str): [ 输出的日志信息 ]
 
         """
 
@@ -130,17 +112,12 @@ class Log(object):
 
     def error(self, message):
         """
-        [ ERROR ]
-        * 无
+        [ 记录 ERROR ]
 
-        [ 必要参数 ]
-        * 无
+        * NOT MESSAGE
 
-        [ 可选参数 ]
-        * 无
-
-        [ 返回内容 ]
-        * 无
+        Args:
+            message (str): [ 输出的日志信息 ]
 
         """
 
@@ -148,17 +125,12 @@ class Log(object):
 
     def critical(self, message):
         """
-        [ CRITICAL ]
-        * 无
+        [ 记录 CRITICAL ]
 
-        [ 必要参数 ]
-        * 无
+        * NOT MESSAGE
 
-        [ 可选参数 ]
-        * 无
-
-        [ 返回内容 ]
-        * 无
+        Args:
+            message (str): [ 输出的日志信息 ]
 
         """
 
@@ -167,16 +139,8 @@ class Log(object):
     def _creation_base_handle(self):
         """
         [ 创建默认流处理器 ]
-        * 无
 
-        [ 必要参数 ]
-        * 无
-
-        [ 可选参数 ]
-        * 无
-
-        [ 返回内容 ]
-        * 无
+        * NOT MESSAGE
 
         """
 
@@ -192,17 +156,9 @@ class Log(object):
     def _creation_file_handle(self):
         """
         [ 创建文件流处理器 ]
-        * 无
-
-        [ 必要参数 ]
-        * 无
-
-        [ 可选参数 ]
-        * 无
-
-        [ 返回内容 ]
-        * 无
 
+        * NOT MESSAGE
+        
         """
 
         # 创建当前项目的日志根目录
@@ -226,3 +182,23 @@ class Log(object):
             file_handle.setLevel(v)
             # 注册处理器
             self._logger.addHandler(file_handle)
+
+
+class CreationLogLivingError(Exception):
+
+    def __init__(self, message: str):
+        """
+        [ 创建日志实例异常 ]
+
+        * NOT MESSAGE
+
+        Args:
+            message (str): [ 输出的错误信息 ]
+
+        """
+
+        self.message = message
+    
+    def __str__(self) -> str:
+
+        return f"创建日志实例异常:: { self.message }"
