@@ -19,6 +19,8 @@ import psutil
 
 from multiprocessing.dummy import Pool
 from multiprocessing.dummy import Manager
+from multiprocessing.dummy import Lock
+from multiprocessing.dummy import Queue
 
 from rains.common.log import Log
 
@@ -26,63 +28,59 @@ from rains.common.log import Log
 class RunPool(object):
     """
     [ 运行池 ]
-    * 无
+
+    * NOT MESSAGE
 
     """
 
-    _log = Log()
-    """ 日志服务 """
+    _log: Log = Log()
+    """ [ 日志服务 ] """
 
     _pool: Pool
-    """ 进程池 """
+    """ [ 进程池 ] """
 
-    _core_queue: Manager().Queue
-    """ 核心队列 """
+    _core_queue: Queue
+    """ [ 核心队列 ] """
 
-    _task_queue: Manager().Queue
-    """ 任务队列 """
+    _task_queue: Queue
+    """ [ 任务队列 ] """
 
     _pool_state: bool
-    """ 进程池运作状态 """
+    """ [ 进程池运作状态 ] """
 
     _sign_task_count: int
-    """ 注册的任务数量 """
+    """ [ 注册的任务数量 ] """
 
     _max_quantity_pool: int = 3
-    """ 进程最大阈值 """
+    """ [ 进程最大阈值 ] """
 
     _max_quantity_core: int = 5
-    """ 核心最大阈值 """
+    """ [ 核心最大阈值 ] """
 
     _max_quantity_task: int = 20
-    """ 任务最大阈值 """
+    """ [ 任务最大阈值 ] """
 
-    _lock_from_core_queue: Manager().Lock
-    """ 核心队列互斥锁 """
+    _lock_from_core_queue: Lock
+    """ [ 核心队列互斥锁 ] """
 
-    _lock_from_task_queue: Manager().Lock
-    """ 任务队列互斥锁 """
+    _lock_from_task_queue: Lock
+    """ [ 任务队列互斥锁 ] """
 
-    _lock_from_pool_state: Manager().Lock
-    """ 进程池运作状态互斥锁 """
+    _lock_from_pool_state: Lock
+    """ [ 进程池运作状态互斥锁 ] """
 
-    _lock_from_task_count: Manager().Lock
-    """ 注册的任务数量互斥锁 """
+    _lock_from_task_count: Lock
+    """ [ 注册的任务数量互斥锁 ] """
 
     def __init__(self, cores: list, tasks: list):
         """
-        [ 初始化 ]
-        * 无
+        [ 运行池 ]
 
-        [ 必要参数 ]
-        * cores (list) : 核心列表
-        * tasks (list) : 任务列表
+        * 初始化。
 
-        [ 可选参数 ]
-        * 无
-
-        [ 返回内容 ]
-        * 无
+        Args:
+            cores (list): [ 核心列表 ]
+            tasks (list): [ 任务列表 ]
 
         """
 
@@ -101,16 +99,8 @@ class RunPool(object):
     def _initialization(self):
         """
         [ 初始化进程池 ]
-        * 无
 
-        [ 必要参数 ]
-        * 无
-
-        [ 可选参数 ]
-        * 无
-
-        [ 返回内容 ]
-        * 无
+        * NOT MESSAGE
 
         """
 
@@ -133,16 +123,8 @@ class RunPool(object):
     def running(self):
         """
         [ 运行 ]
-        * 无
 
-        [ 必要参数 ]
-        * 无
-
-        [ 可选参数 ]
-        * 无
-
-        [ 返回内容 ]
-        * 无
+        * NOT MESSAGE
 
         """
 
@@ -155,9 +137,7 @@ class RunPool(object):
 
             self._pool_state = True
 
-            for i in range(count):
-                # 强制 GC 回收垃圾避免内存溢出
-                gc.collect()
+            for _i in range(count):
 
                 # 驱动冷启动时会占用大量的 CPU 资源，为避免因为 CPU 占用率过高导致进程启动异常
                 # 每隔 2 秒检查 CPU 占用率，只有 CPU 占用率少于 50 时才会启动进程
@@ -177,25 +157,20 @@ class RunPool(object):
     def _emit(self):
         """
         [ 触发工作流 ]
-        * 无
 
-        [ 必要参数 ]
-        * 无
-
-        [ 可选参数 ]
-        * 无
-
-        [ 返回内容 ]
-        * 无
+        * NOT MESSAGE
 
         """
 
+        # 强制 GC 回收垃圾避免内存溢出
+        gc.collect()
+
         # 取出队列中的核心与任务
         task = self._task_queue.get()
         core = self._core_queue.get()
 
         # 执行核心的 running 函数
-        r = core.start_task(task)
+        core.start_task(task)
 
         # 触发回调
         self._function_call_back()
@@ -204,22 +179,12 @@ class RunPool(object):
         with self._lock_from_core_queue:
             self._core_queue.put(core)
 
-        return r
-
     def _function_call_back(self):
         """
         [ 触发回调 ]
+
         * 该回调将消耗任务数量。
 
-        [ 必要参数 ]
-        * 无
-
-        [ 可选参数 ]
-        * 无
-
-        [ 返回内容 ]
-        * 无
-
         """
 
         with self._lock_from_task_count:
