@@ -1,4 +1,8 @@
 
+import os
+import sys
+sys.path.append(os.path.dirname(os.path.dirname(os.path.realpath(__file__))))
+
 from rains.kit.web import *
 from rains.common.run_pool import RunPool
 
@@ -45,15 +49,6 @@ class TaskTest(WebTask):
         self.plant.view.to_url('http://manage.dev-tea.cblink.net/')
 
     def case_01(self):
-        """
-        登录失败
-        """
-        self.user_input.input.send('admin@baocai.us')
-        self.password_input.input.send('654321')
-        self.login_button.mouse.tap()
-        return self.create_button.get.in_page() is not True
-
-    def case_02(self):
         """
         登录成功
         """
@@ -64,15 +59,6 @@ class TaskTest(WebTask):
 
 
 if __name__ == '__main__':
-
-    # core = WebCore()
-    # core.start_task(TaskTest)
-
-    tasks = []
-    for i in range(1):
-        tasks.append(TaskTest)
-
-    RunPool(
-        cores=[WebCore()],
-        tasks=tasks
-    ).running()
+    from rains.common.rains_server import RainsServer
+    rains_server = RainsServer()
+    rains_server.running()
